## This file contains the non-final version of the data analyses for
##  Expt 1 presented in the paper:
#   Shravan Vasishth, Katja Suckow, Richard Lewis, and Sabine Kern.
#   Short-term forgetting in sentence comprehension:
#   Crosslinguistic evidence from head-final structures.
#   Submitted to Language and Cognitive Processes, 2007.

library(lme4)
library(car)

library(Hmisc)
library(xtable)
library(MASS)

## analyzing question-responses using logistic regression
## question responses
alldataq <- read.table("../../data/allquestions.txt")
colnames(alldataq) <- c("subject","expt","item","condition","question","response","correct","qrt")

## remove practice items
alldataq <- subset(alldataq,expt!="practice")

## mean and se of all responses:
mean(with(alldataq,tapply(correct,subject,mean)))
se(with(alldataq,tapply(correct,subject,mean)))

alldataq.gug <- subset(alldataq,expt=="gug")
alldataq.gug$condition <- factor(alldataq.gug$condition)

## grammaticality factor: if grammatical, 0, if ungrammatical 1
alldataq.gug$gram <- ifelse(alldataq.gug$condition%in%c("a","b"),0,1)

with(alldataq.gug,tapply(correct,gram,mean,na.rm=TRUE))*100
with(alldataq.gug,tapply(correct,gram,se))*100

## logistic regression model
summary(lmer(correct~gram+(1|subject)+(1|item),
             family=binomial(),alldataq.gug))



## interpretation:
## Intercept: when gram==0, the probability of
## giving a correct answer is significantly higher than 50% (chance):
## exp(0.3139=1.368753
## p_correct=1.368753/(1+1.368753)=0.5778369

## coefficient for gram:
## exp(0.3416)=1.407197
## 1.368753+1.407197
## p_correct=2.77595/(1+2.77595)=0.735166
## the probability of giving a correct answer is higher in the
## ungrammatical case (coded 1)
## and this is significantly above chance

